@@ -30,8 +30,7 @@
 
 #include <glib/gi18n-lib.h>
 
-#include <e-util/e-config.h>
-#include <e-util/e-plugin.h>
+#include <e-util/e-util.h>
 
 #include <libekolab/camel-kolab-imapx-store.h>
 
