@@ -434,7 +434,7 @@ imapx_metadata_parse_annotation_response (CamelImapxMetadata *md,
 		}
 
 		/* add value data to attribute structure */
-		len = strlen ((gchar*) attrib_value);
+		len = (guint) strlen ((gchar*) attrib_value);
 		ma->data[acc] = g_byte_array_new ();
 		g_byte_array_append (ma->data[acc],
 		                     attrib_value,
@@ -697,7 +697,7 @@ camel_imapx_metadata_new_commandlist (CamelImapxMetadata *md)
 						g_string_append (cmd, "\"");
 						g_string_append_len (cmd,
 						                     (gchar *) ma->data[acc]->data,
-						                     (gssize) ma->data[acc]->len);
+						                     (gssize) ma->data[acc]->len - 1);
 						g_string_append (cmd, "\"");
 						break;
 					default:
@@ -897,4 +897,31 @@ camel_imapx_metadata_get_attrib_from_metadata (CamelImapxMetadata *md,
 	return ma;
 }
 
+gboolean
+camel_imapx_metadata_remove_metadata (CamelImapxMetadata *md,
+                                      const gchar *mailbox_name)
+{
+	gboolean found = FALSE;
+	
+	if (md == NULL)
+		return FALSE;
+	if (mailbox_name == NULL)
+		return FALSE;
+
+	/* (acquire md lock ) */
+	g_mutex_lock (&(md->md_lock));
+
+	if (md->mboxes == NULL)
+		goto skip;
+	
+	found = g_hash_table_remove (md->mboxes, mailbox_name);
+
+ skip:
+	
+	/* (release md lock ) */
+	g_mutex_unlock (&(md->md_lock));
+
+	return found;
+}
+
 /*----------------------------------------------------------------------------*/
